[//]: # (install, help) Installing eh
# Installing

Install with `pip install eh`. You may want to use `sudo` if you want it available everywhere.

## 

### Note: 

With some versions of linux it will install it into `~/.local/bin` when you do **not** use `sudo`. Ensure that this directory is in your `PATH` if you want to run eh.
